package com.fluig.sample.services;

import com.google.gson.Gson;
import com.totvs.technology.ecm.dm.ws.ApproverDtoArray;
import com.totvs.technology.ecm.dm.ws.Attachment;
import com.totvs.technology.ecm.dm.ws.AttachmentArray;
import com.totvs.technology.ecm.dm.ws.DocumentDto;
import com.totvs.technology.ecm.dm.ws.DocumentDtoArray;
import com.totvs.technology.ecm.dm.ws.DocumentSecurityConfigDtoArray;
import com.totvs.technology.ecm.dm.ws.DocumentService;
import com.totvs.technology.ecm.dm.ws.ECMDocumentServiceService;
import com.totvs.technology.ecm.dm.ws.Exception_Exception;
import com.totvs.technology.ecm.dm.ws.RelatedDocumentDtoArray;
import com.totvs.technology.ecm.dm.ws.WebServiceMessageArray;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.net.MalformedURLException;
import java.net.URL;

public class SampleDocumentServlet extends HttpServlet {

    private static final long serialVersionUID = 1L;
    private static final String URL = "http://<FLUIG_SERVER_IP>:<FLUIG_SERVER_PORT>";

    private final Gson gson;

    public SampleDocumentServlet() {
        this.gson = new Gson();
    }

    @Override
    public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException {
        // Set response content type
        response.setContentType("application/json; charset=UTF-8");

        // Actual logic goes here.
        PrintWriter out = response.getWriter();

        int parent = 0;
        if (request.getParameter("parent") != null) {
            parent = Integer.parseInt(request.getParameter("parent"));
        }

        String user = "your-user";
        if (request.getParameter("user") != null) {
            user = request.getParameter("user");
        }

        String password = "<LOGIN_USUARIO>";
        if (request.getParameter("password") != null) {
            password = request.getParameter("password");
        }

        int tenantId = 1;
        if (request.getParameter("tenantid") != null) {
            tenantId = Integer.parseInt(request.getParameter("tenantid"));
        }

        String fileName = "file-name";
        if (request.getParameter("filename") != null) {
            fileName = request.getParameter("filename");
        }

        String volumePath = "/opt/fluig/volume";
        if (request.getParameter("volumepath") != null) {
            volumePath = request.getParameter("volumepath");
        }

        DocumentDto document = new DocumentDto();
        document.setParentDocumentId(parent);
        document.setColleagueId(user);
        document.setPublisherId(user);
        document.setCompanyId(tenantId);
        document.setDocumentType("DOCUMENT");
        document.setDocumentDescription("Document description");
        document.setCreateDateInMilliseconds(System.currentTimeMillis());
        document.setForAproval(false);
        document.setInheritSecurity(true);
        document.setOnCheckout(false);
        document.setSecurityLevel(3);
        document.setTranslated(false);
        document.setUpdateIsoProperties(false);
        document.setVersion(1000);
        document.setVersionOption("");

        DocumentDtoArray documentDtoArray = new DocumentDtoArray();
        documentDtoArray.getItem().add(document);

        Attachment attachment = new Attachment();
        attachment.setAttach(false);
        attachment.setDescriptor(false);
        attachment.setEditing(false);
        attachment.setFileName(fileName);
        attachment.setFullPatch(volumePath + File.separatorChar + "upload"
                + File.separatorChar + user + File.separatorChar + fileName);
        attachment.setPrincipal(true);

        AttachmentArray attachmentArray = new AttachmentArray();
        attachmentArray.getItem().add(attachment);

        ECMDocumentServiceService service = new ECMDocumentServiceService(getURLws("ECMDocumentService"));
        DocumentService documentService = service.getDocumentServicePort();
        try {
            WebServiceMessageArray resultCreate = documentService.createDocument(user, password, tenantId,
                    documentDtoArray, attachmentArray, new DocumentSecurityConfigDtoArray(), new ApproverDtoArray(),
                    new RelatedDocumentDtoArray());

            String jsonResultCreate = gson.toJson(resultCreate);
            out.println("{\"content\":" + jsonResultCreate + ", \"message\":" + gson.toJson(document) + "}");
        } catch (Exception_Exception e) {
            response.setStatus(500);
            out.println("{\"content\":" + e.getMessage() + ", \"message\":" + gson.toJson(document) + "}");
        }
    }

    public URL getURLws(String service) throws MalformedURLException {
        String wsURL = URL + "/webdesk/" + service + "?wsdl";
        return new URL(wsURL);
    }
}
